@@ -34,7 +34,7 @@ namespace Components\Kb\Admin;
 
 if (!\User::authorise('core.manage', 'com_kb'))
 {
-	throw new \Exception(\Lang::txt('JERROR_ALERTNOAUTHOR'), 403);
+	\App::abort(403, \Lang::txt('JERROR_ALERTNOAUTHOR'));
 }
 
 // Include scripts
@@ -42,21 +42,20 @@ require_once(dirname(__DIR__) . DS . 'models' . DS . 'archive.php');
 require_once(__DIR__ . DS . 'helpers' . DS . 'html.php');
 require_once(__DIR__ . DS . 'helpers' . DS . 'permissions.php');
 
-$controllerName = \Request::getCmd('controller', 'categories');
+$controllerName = \Request::getCmd('controller', 'articles');
 if (!file_exists(__DIR__ . DS . 'controllers' . DS . $controllerName . '.php'))
 {
-	$controllerName = 'categories';
+	$controllerName = 'articles';
 }
 
 \Submenu::addEntry(
-	\Lang::txt('COM_KB_CATEGORIES'),
-	\Route::url('index.php?option=com_kb&id=0', false),
-	$controllerName == 'categories'
+	\Lang::txt('COM_KB_ARTICLES'),
+	\Route::url('index.php?option=com_kb&controller=articles', false),
+	$controllerName == 'articles'
 );
 \Submenu::addEntry(
-	\Lang::txt('COM_KB_ARTICLES'),
-	\Route::url('index.php?option=com_kb&controller=articles&id=0', false),
-	$controllerName == 'articles'
+	\Lang::txt('COM_KB_CATEGORIES'),
+	\Route::url('index.php?option=com_categories&extension=com_kb', false)
 );
 
 require_once(__DIR__ . DS . 'controllers' . DS . $controllerName . '.php');
@@ -65,5 +64,3 @@ $controllerName = __NAMESPACE__ . '\\Controllers\\' . ucfirst($controllerName);
 // Instantiate controller
 $controller = new $controllerName();
 $controller->execute();
-$controller->redirect();
-
