@@ -78,7 +78,7 @@ function submitbutton(pressbutton)
 {
 	var form = document.getElementById('adminForm');
 
-	if (pressbutton == 'clearTerms') {
+	if (pressbutton == 'clearTerms' || pressbutton == 'remove') {
 		var res = confirm('Are you sure? Make sure you know what you\'re doing, as this action cannot be undone!');
 
 		if (!res) {
@@ -341,4 +341,4 @@ function submitbutton(pressbutton)
 	<input type="hidden" name="filter_order" value="<?php echo $this->filters['sort']; ?>" />
 	<input type="hidden" name="filter_order_Dir" value="<?php echo $this->filters['sort_Dir']; ?>" />
 	<?php echo Html::input('token'); ?>
-</form>
\ No newline at end of file
+</form>
