@@ -53,7 +53,9 @@ $options = array();
 				<form action="<?php echo Route::url($base); ?>">
 					<label for="report-type"><?php echo Lang::txt('COM_TIME_REPORTS_SELECT_REPORT_TYPE'); ?>: </label>
 					<?php foreach ($this->reports as $report) : ?>
-						<?php $options[] = Html::select('option', $report->name, ucwords($report->name), 'value', 'text'); ?>
+						<?php $element = 'plg_time_' . $report->name; ?>
+						<?php Lang::load(strtolower($element), PATH_CORE . DS . 'plugins' . DS . 'time' . DS . $report->name); ?>
+						<?php $options[] = Html::select('option', $report->name, Lang::txt(strtoupper($element . '_display_name')), 'value', 'text'); ?>
 					<?php endforeach; ?>
 					<?php echo Html::select('genericlist', $options, 'report_type', null, 'value', 'text', $this->report_type); ?>
 					<button class="btn btn-success"><?php echo Lang::txt('COM_TIME_REPORTS_BEGIN'); ?></button>
