@@ -33,10 +33,30 @@
 // No direct access
 defined('_HZEXEC_') or die();
 
+
 $this->css();
 
 ?>
 
+<?php 
+// Output the submenu view
+$view = new \Hubzero\Plugin\View(array(
+	'folder' => 'groups',
+	'element' => 'projects',
+	'name'   => 'partials',
+	'layout' => 'submenu'
+));
+
+// Pass Variables through to the view
+$view->group = $this->group;
+$view->projectcount = $this->projectcount;
+$view->newcount = $this->newcount;
+$view->tab = 'updates';
+$view->display();
+
+?>
+
+<?php if (0): ?>
 <ul id="page_options" class="pluginOptions">
 	<li>
 		<a class="icon-add add btn showinbox"  href="<?php echo Route::url('index.php?option=com_projects&task=start&gid=' . $this->group->get('gidNumber')); ?>">
@@ -57,6 +77,7 @@ $this->css();
 		</a>
 	</li>
 </ul>
+<?php endif;?>
 
 <section class="main section" id="s-projects">
 	<div id="project-updates">
@@ -64,4 +85,4 @@ $this->css();
 		echo $this->content;
 		?>
 	</div>
-</section>
\ No newline at end of file
+</section>
